@@ -4,7 +4,7 @@ use base 'Exporter';
 use vars '@EXPORT';
 use Test::MockObject;
 
-@EXPORT = qw(fake_request http_request write_file);
+@EXPORT = qw(fake_request http_request write_file get_response_for_request);
 
 my $path = undef;
 sub path {
@@ -25,6 +25,7 @@ sub fake_request($$) {
 	my $req = Test::MockObject->new;
 	$req->mock('request_method', sub { method(@_) });
 	$req->mock('path_info', sub { path(@_) });
+    $req->mock('script_name', sub { undef });
 	$req->mock('Vars', sub { {} });
 	
 	$req->request_method($method);
@@ -48,4 +49,11 @@ sub write_file {
     close CONF;
 }
 
+sub get_response_for_request {
+    my ($method, $path) = @_;
+    my $cgi = fake_request($method => $path);
+    Dancer::SharedData->cgi($cgi);
+    Dancer::Renderer::get_action_response();
+}
+
 'TestUtils';
